@@ -13,7 +13,7 @@ self.addpkg2db("local", lp1)
 lp2 = pmpkg("pkg2")
 self.addpkg2db("local", lp2)
 
-self.args = "-S %s --ask=4" % " ".join([p.name for p in sp1, sp2])
+self.args = "-S %s --ask=4" % " ".join([p.name for p in (sp1, sp2)])
 
 self.addrule("PACMAN_RETCODE=1")
 self.addrule("PKG_EXIST=pkg1")
